Path to the archived target store directory
tar_archive_store(package, pipeline, store = targets::tar_config_get("store"))A scalar character of the path to the archived target store directory.
A scalar character of the package name.
A scalar character of the pipeline name.
Character of length 1, path to the
targets data store. Defaults to tar_config_get("store"),
which in turn defaults to _targets/.
When you set this argument, the value of tar_config_get("store")
is temporarily changed for the current function call.
See tar_config_get() and tar_config_set() for details
about how to set the data store path persistently
for a project.