Returns the names of the pipelines bundled in a package's
inst/tarchives directory. Use it to discover which pipelines are
available before running them with tar_make_archive() or inspecting their
targets with tar_manifest_archive().
Usage
tar_archive_pipelines(
package,
envir = parent.frame(),
script = targets::tar_config_get("script")
)Arguments
- package
A scalar character of the package name.
- envir
An environment used to resolve
package, so that a package currently loaded withpkgload::load_all()(e.g. during interactive package development) is resolved to its source directory instead of its installed one. Defaults to the calling environment.- script
Character of length 1, path to the target script file. Defaults to
tar_config_get("script"), which in turn defaults to_targets.R. When you set this argument, the value oftar_config_get("script")is temporarily changed for the current function call. Seetar_script(),tar_config_get(), andtar_config_set()for details about the target script file and how to set it persistently for a project.
Value
A character vector of pipeline names. A pipeline is a directory in
inst/tarchives that contains a target script file (script), so the
shared R/ helper directory is not included.
See also
tar_manifest_archive() to list the targets within a pipeline.